LnReturn

Struct LnReturn 

pub struct LnReturn<T, V> { /* private fields */ }
Computes the natural logarithm and keep track of the last value. Usually applied to price data.

Implementations

Source

impl<T, V> LnReturn<T, V>
where T: Float, V: View<T>,

pub fn new(view: V) -> Self

Create a new instance of Self with a chained View, whose output will be used to feed the ln return computation.