pub struct Vsct<T: Float, V> { /* private fields */ }Expand description
Variance Stabilizing Centering Transform Sliding Window
Implementations
Sourceimpl<T, V> Vsct<T, V>
impl<T, V> Vsct<T, V>
Sourcepub fn new(view: V, window_len: NonZeroUsize) -> Self
pub fn new(view: V, window_len: NonZeroUsize) -> Self
Create a new Variance Stabilizing Centering Transform with a chained View and a given sliding window length
Sourcepub fn window_len(&self) -> NonZeroUsize
pub fn window_len(&self) -> NonZeroUsize
The sliding window length.