pub trait View<T: Float> {
// Required methods
fn update(&mut self, val: T);
fn last(&self) -> Option<T>;
}Expand description
The most important Trait, defining methods which each sliding feature needs to implement
pub trait View<T: Float> {
// Required methods
fn update(&mut self, val: T);
fn last(&self) -> Option<T>;
}The most important Trait, defining methods which each sliding feature needs to implement